[vte/vte-next: 195/223] Rename



commit 876b6276d7a306d07d6b8babbdf3b1e607d4a4b0
Author: Christian Persch <chpe gnome org>
Date:   Thu Jun 16 20:32:58 2011 +0200

    Rename

 doc/reference/vte-sections.txt |   18 +++++++++---------
 src/vte-private.h              |    6 +++---
 src/vte.c                      |   36 ++++++++++++++++++------------------
 src/vteenums.h                 |   22 +++++++++++-----------
 src/vteseq.c                   |    2 +-
 5 files changed, 42 insertions(+), 42 deletions(-)
---
diff --git a/doc/reference/vte-sections.txt b/doc/reference/vte-sections.txt
index 8c0267a..d4a49a8 100644
--- a/doc/reference/vte-sections.txt
+++ b/doc/reference/vte-sections.txt
@@ -2,9 +2,9 @@
 <FILE>vte-terminal</FILE>
 <TITLE>VteTerminal</TITLE>
 VteTerminal
-VteTerminalCursorBlinkMode
-VteTerminalCursorShape
-VteTerminalEffect
+VteCursorBlinkMode
+VteCursorShape
+VteEffect
 VteEraseBinding
 VteWriteFlags
 VteSelectionFunc
@@ -51,12 +51,12 @@ vte_get_default_emulation
 vte_get_user_shell
 
 <SUBSECTION Standard>
-VTE_TYPE_TERMINAL_CURSOR_BLINK_MODE
-vte_terminal_cursor_blink_mode_get_type
-VTE_TYPE_TERMINAL_CURSOR_SHAPE
-vte_terminal_cursor_shape_get_type
-VTE_TYPE_TERMINAL_EFFECT
-vte_terminal_effect_get_type
+VTE_TYPE_CURSOR_BLINK_MODE
+vte_cursor_blink_mode_get_type
+VTE_TYPE_CURSOR_SHAPE
+vte_cursor_shape_get_type
+VTE_TYPE_EFFECT
+vte_effect_get_type
 VTE_TYPE_ERASE_BINDING
 vte_erase_binding_get_type
 VTE_TYPE_WRITE_FLAGS
diff --git a/src/vte-private.h b/src/vte-private.h
index 8e72ae1..a6e46d2 100644
--- a/src/vte-private.h
+++ b/src/vte-private.h
@@ -409,8 +409,8 @@ struct _VteTerminalRealPrivate {
         gboolean invalidated_all;       /* pending refresh of entire terminal */
 
         /* Cursor */
-        VteTerminalCursorShape cursor_shape;
-        VteTerminalCursorBlinkMode cursor_blink_mode;
+        VteCursorShape cursor_shape;
+        VteCursorBlinkMode cursor_blink_mode;
         float cursor_aspect_ratio;
         gboolean cursor_blink_state;
         guint cursor_blink_tag;           /* cursor blinking timeout ID */
@@ -461,7 +461,7 @@ gboolean _vte_terminal_size_to_grid_size(VteTerminal *terminal,
 void _vte_terminal_set_effect_color(VteTerminal *terminal,
                                     int entry,
                                     const GdkRGBA *rgba,
-                                    VteTerminalEffect effect,
+                                    VteEffect effect,
                                     gboolean override);
 
 gboolean _vte_terminal_is_word_char(VteTerminal *terminal, gunichar c);
diff --git a/src/vteseq.c b/src/vteseq.c
index bfce09b..ef7d982 100644
--- a/src/vteseq.c
+++ b/src/vteseq.c
@@ -3187,7 +3187,7 @@ vte_sequence_handler_change_cursor_color (VteBuffer *buffer, GValueArray *params
 
 		if (vte_parse_color (name, &color))
 			_vte_terminal_set_effect_color(buffer->pvt->terminal, VTE_CUR_BG, &color,
-                                                       VTE_TERMINAL_EFFECT_COLOR, TRUE);
+                                                       VTE_EFFECT_COLOR, TRUE);
 		else if (strcmp (name, "?") == 0) {
 			gchar buf[128];
 			g_snprintf (buf, sizeof (buf),



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/vte.c b/src/vte.c
index f96daa9..280d09a 100644
--- a/src/vte.c
+++ b/src/vte.c
@@ -4241,7 +4241,7 @@ void
 _vte_terminal_set_effect_color(VteTerminal *terminal,
                                int entry,
                                const GdkRGBA *rgba,
-                               VteTerminalEffect effect,
+                               VteEffect effect,
                                gboolean override)
 {
         VteTerminalPrivate *pvt = terminal->pvt;
@@ -4259,7 +4259,7 @@ _vte_terminal_set_effect_color(VteTerminal *terminal,
 
         vte_terminal_set_color_internal(terminal, entry, rgba, override);
 
-        color_set = (effect == VTE_TERMINAL_EFFECT_COLOR);
+        color_set = (effect == VTE_EFFECT_COLOR);
         switch (entry) {
         case VTE_CUR_BG:
                 pvt->cursor_color_set = color_set;
@@ -4442,10 +4442,10 @@ vte_terminal_update_cursor_style(VteTerminal *terminal)
                              "cursor-aspect-ratio", &aspect,
                              NULL);
 
-        if ((VteTerminalCursorBlinkMode)blink_mode != term_pvt->cursor_blink_mode) {
-                term_pvt->cursor_blink_mode = (VteTerminalCursorBlinkMode)blink_mode;
+        if ((VteCursorBlinkMode)blink_mode != term_pvt->cursor_blink_mode) {
+                term_pvt->cursor_blink_mode = (VteCursorBlinkMode)blink_mode;
 
-                switch ((VteTerminalCursorBlinkMode)blink_mode) {
+                switch ((VteCursorBlinkMode)blink_mode) {
                 case VTE_CURSOR_BLINK_SYSTEM:
                         g_object_get(gtk_widget_get_settings(GTK_WIDGET(terminal)),
                                                              "gtk-cursor-blink", &blinks,
@@ -4462,8 +4462,8 @@ vte_terminal_update_cursor_style(VteTerminal *terminal)
                 vte_terminal_set_cursor_blinks_internal(terminal, blinks);
         }
 
-        if ((VteTerminalCursorShape)cursor_shape != term_pvt->cursor_shape) {
-                term_pvt->cursor_shape = (VteTerminalCursorShape)cursor_shape;
+        if ((VteCursorShape)cursor_shape != term_pvt->cursor_shape) {
+                term_pvt->cursor_shape = (VteCursorShape)cursor_shape;
                 _vte_invalidate_cursor_once(terminal, FALSE);
         }
 
@@ -11428,7 +11428,7 @@ vte_terminal_class_init(VteTerminalClass *klass)
         gtk_widget_class_install_style_property
                 (widget_class,
                  g_param_spec_enum ("cursor-blink-mode", NULL, NULL,
-                                    VTE_TYPE_TERMINAL_CURSOR_BLINK_MODE,
+                                    VTE_TYPE_CURSOR_BLINK_MODE,
                                     VTE_CURSOR_BLINK_SYSTEM,
                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
@@ -11442,7 +11442,7 @@ vte_terminal_class_init(VteTerminalClass *klass)
         gtk_widget_class_install_style_property
                 (widget_class,
                  g_param_spec_enum ("cursor-shape", NULL, NULL,
-                                    VTE_TYPE_TERMINAL_CURSOR_SHAPE,
+                                    VTE_TYPE_CURSOR_SHAPE,
                                     VTE_CURSOR_SHAPE_BLOCK,
                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
@@ -11503,7 +11503,7 @@ vte_terminal_class_init(VteTerminalClass *klass)
          *
          * Controls how the terminal will draw the cursor.
          *
          * If set to %VTE_TERMINAL_EFFECT_COLOR, the cursor is drawn
          * with the background color from the #VteTerminal:cursor-background-color
          * style property.
          *
@@ -11512,8 +11512,8 @@ vte_terminal_class_init(VteTerminalClass *klass)
         gtk_widget_class_install_style_property
                 (widget_class,
                  g_param_spec_enum ("cursor-effect", NULL, NULL,
-                                    VTE_TYPE_TERMINAL_EFFECT,
-                                    VTE_TERMINAL_EFFECT_REVERSE,
+                                    VTE_TYPE_EFFECT,
+                                    VTE_EFFECT_REVERSE,
                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
         /**
@@ -11521,7 +11521,7 @@ vte_terminal_class_init(VteTerminalClass *klass)
          *
          * Controls how the terminal will draw reversed text.
          *
          * If set to %VTE_TERMINAL_EFFECT_COLOR, reversed text is drawn
          * with the background color from the #VteTerminal:reverse-background-color
          * style property.
          *
@@ -11530,8 +11530,8 @@ vte_terminal_class_init(VteTerminalClass *klass)
         gtk_widget_class_install_style_property
                 (widget_class,
                  g_param_spec_enum ("reverse-effect", NULL, NULL,
-                                    VTE_TYPE_TERMINAL_EFFECT,
-                                    VTE_TERMINAL_EFFECT_REVERSE,
+                                    VTE_TYPE_EFFECT,
+                                    VTE_EFFECT_REVERSE,
                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
         /**
@@ -11539,7 +11539,7 @@ vte_terminal_class_init(VteTerminalClass *klass)
          *
          * Controls how the terminal will draw selected text.
          *
          * If set to %VTE_TERMINAL_EFFECT_COLOR, selected text is drawn
          * with the background color from the #VteTerminal:selection-background-color
          * style property.
          *
@@ -11548,8 +11548,8 @@ vte_terminal_class_init(VteTerminalClass *klass)
         gtk_widget_class_install_style_property
                 (widget_class,
                  g_param_spec_enum ("selection-effect", NULL, NULL,
-                                    VTE_TYPE_TERMINAL_EFFECT,
-                                    VTE_TERMINAL_EFFECT_REVERSE,
+                                    VTE_TYPE_EFFECT,
+                                    VTE_EFFECT_REVERSE,
                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
         /* Keybindings */
@@ -11503,7 +11503,7 @@ vte_terminal_class_init(VteTerminalClass *klass)
          * Controls how the terminal will draw the cursor.
          *
-         * If set to %VTE_TERMINAL_EFFECT_COLOR, the cursor is drawn
+         * If set to %VTE_EFFECT_COLOR, the cursor is drawn
          * with the background color from the #VteTerminal:cursor-background-color
          * style property.
@@ -11521,7 +11521,7 @@ vte_terminal_class_init(VteTerminalClass *klass)
          * Controls how the terminal will draw reversed text.
          *
-         * If set to %VTE_TERMINAL_EFFECT_COLOR, reversed text is drawn
+         * If set to %VTE_EFFECT_COLOR, reversed text is drawn
          * with the background color from the #VteTerminal:reverse-background-color
          * style property.
@@ -11539,7 +11539,7 @@ vte_terminal_class_init(VteTerminalClass *klass)
          * Controls how the terminal will draw selected text.
          *
-         * If set to %VTE_TERMINAL_EFFECT_COLOR, selected text is drawn
+         * If set to %VTE_EFFECT_COLOR, selected text is drawn
          * with the background color from the #VteTerminal:selection-background-color
          * style property.
diff --git a/src/vteenums.h b/src/vteenums.h
index 5cbf1dc..dcdcae0 100644
--- a/src/vteenums.h
+++ b/src/vteenums.h
@@ -46,7 +46,7 @@ typedef enum {
 } VteEraseBinding;
 
 /**
- * VteTerminalCursorBlinkMode:
+ * VteCursorBlinkMode:
  * @VTE_CURSOR_BLINK_SYSTEM: Follow GTK+ settings for cursor blinking.
  * @VTE_CURSOR_BLINK_ON: Cursor blinks.
  * @VTE_CURSOR_BLINK_OFF: Cursor does not blink.
@@ -58,10 +58,10 @@ typedef enum {
         VTE_CURSOR_BLINK_SYSTEM,
         VTE_CURSOR_BLINK_ON,
         VTE_CURSOR_BLINK_OFF
-} VteTerminalCursorBlinkMode;
+} VteCursorBlinkMode;
 
 /**
- * VteTerminalCursorShape:
+ * VteCursorShape:
  * @VTE_CURSOR_SHAPE_BLOCK: Draw a block cursor.  This is the default.
  * @VTE_CURSOR_SHAPE_IBEAM: Draw a vertical bar on the left side of character.
  * This is similar to the default cursor for other GTK+ widgets.
@@ -74,17 +74,17 @@ typedef enum {
         VTE_CURSOR_SHAPE_BLOCK,
         VTE_CURSOR_SHAPE_IBEAM,
         VTE_CURSOR_SHAPE_UNDERLINE
-} VteTerminalCursorShape;
+} VteCursorShape;
 
 /**
  * VteTerminalEffect:
  * @VTE_TERMINAL_EFFECT_REVERSE: Text is draw with foreground and background color reversed.
  * @VTE_TERMINAL_EFFECT_COLOR: Text is drawn with the background color from the corresponding style property.
  */
 typedef enum {
-        VTE_TERMINAL_EFFECT_REVERSE,
-        VTE_TERMINAL_EFFECT_COLOR
-} VteTerminalEffect;
+        VTE_EFFECT_REVERSE,
+        VTE_EFFECT_COLOR
+} VteEffect;
 
 
 /**
@@ -99,7 +99,7 @@ typedef enum {
 
 /**
  * VteWriteFlags:
- * @VTE_TERMINAL_WRITE_DEFAULT: Write contents as UTF-8 text.  This is the default.
+ * @VTE_WRITE_DEFAULT: Write contents as UTF-8 text.  This is the default.
  *
  * A flag type to determine how terminal contents should be written
  * to an output stream.
@@ -74,17 +74,17 @@ typedef enum {
 
 /**
- * VteTerminalEffect:
- * @VTE_TERMINAL_EFFECT_REVERSE: Text is draw with foreground and background color reversed.
- * @VTE_TERMINAL_EFFECT_COLOR: Text is drawn with the background color from the corresponding style property.
+ * VteEffect:
+ * @VTE_EFFECT_REVERSE: Text is draw with foreground and background color reversed.
+ * @VTE_EFFECT_COLOR: Text is drawn with the background color from the corresponding style property.
  */
 typedef enum {